pub struct StorageDiagnostics {
pub objects: u64,
pub events: u64,
pub links: u64,
pub queues: u64,
pub active_jobs: u64,
pub dead_jobs: u64,
pub journal_bytes: u64,
pub journal_count: u64,
}Expand description
Read-only storage counts used by diagnostics and operator tooling.
Fields
objects: u64Number of stored objects.
events: u64Number of stored events.
links: u64Number of stored links.
queues: u64Number of queues.
active_jobs: u64Number of active queue jobs.
dead_jobs: u64Number of dead-letter jobs.
journal_bytes: u64Current primary-storage journal bytes, when available.
journal_count: u64Number of journals currently retained by the backend, when available.